@@ -2,7 +2,7 @@ package Plack::Middleware::Security::Simple;
 
 # ABSTRACT: A simple security filter for Plack
 
-use v5.8.0;
+use v5.10.0;
 
 use strict;
 use warnings;
@@ -10,17 +10,16 @@ use warnings;
 use parent qw( Plack::Middleware );
 
 use Hash::Match;
-use HTTP::Exception;
 use HTTP::Status qw( HTTP_BAD_REQUEST );
 use Ref::Util qw/ is_plain_arrayref is_plain_hashref /;
 
+use Plack::Response;
 use Plack::Util;
 use Plack::Util::Accessor qw( rules handler );
 
 # RECOMMEND PREREQ: Ref::Util::XS
-# RECOMMEND PREREQ: Plack::Middleware::HTTPExceptions
 
-our $VERSION = 'v0.2.1';
+our $VERSION = 'v0.3.0';
 
 
 sub prepare_app {
@@ -45,7 +44,9 @@ sub prepare_app {
                           . " Blocked $env->{REMOTE_ADDR} $env->{REQUEST_URI}"
                     });
                 }
-                return HTTP::Exception->throw(HTTP_BAD_REQUEST);
+            my $res = Plack::Response->new(HTTP_BAD_REQUEST, [ 'Content-Type' => 'text/plain' ], [ "Bad Request" ] );
+                return $res->finalize;
+
             }
         );
     }
@@ -76,7 +77,7 @@ Plack::Middleware::Security::Simple - A simple security filter for Plack
 
 =head1 VERSION
 
-version v0.2.1
+version v0.3.0
 
 =head1 SYNOPSIS
 
@@ -84,8 +85,6 @@ version v0.2.1
 
   builder {
 
-    enable "HTTPExceptions", rethrow => 1;
-
     enable "Security::Simple",
         rules => [
             PATH_INFO       => qr{^/cgi-bin/},
@@ -124,7 +123,7 @@ L<Plack::Response>, or throws an exception for
 L<Plack::Middleware::HTTPExceptions>.
 
 The default handler will log a warning to the C<psgix.logger>, and
-throw a L<HTTP::Exception> for HTTP 400 (Bad Request).
+return a HTTP 400 (Bad Request) response.
 
 =head1 SEE ALSO
 
